import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  scaleOrdinal,
  schemeCategory10,
  format
} from 'd3';

//import { loadData } from './loadData';


const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'Exports to US & China ($)';
  
  const cValue = data => data['Indicator_desc'];
  
  const color = scaleOrdinal(schemeCategory10);
  

  //console.log(color.domain)
  
  var xValue = d => d['United States of America'];
  const xAxisLabel = 'United States of America';
  
  var yValue = d => d['China'];
  const circleRadius = 8;
  const yAxisLabel = 'China';
  
  const margin = { top: 60, right: 40, bottom: 70, left: 120 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickFormat(format(".2s")) 
    .tickSize(-innerHeight)
    .tickPadding(10);
  
  const yAxis = axisLeft(yScale)
    .tickFormat(format(".2s")) 
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -80)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  const points = g.selectAll('circle').data(data);
  const pointsEnter = points.enter().append('circle')
    
  pointsEnter
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius)
  	  .style('fill', d => color(cValue(d)));

  
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
  
  // Reference: http://bl.ocks.org/weiglemc/6185069
  // draw legend

  
   
  var legend = svg.selectAll(".legend")
      .data(color.domain())
    .enter().append("g")
      .attr("class", "legend")
      .attr("transform", (d, i) => `translate(-40,${(i + 8.5) * 20})`)


  // draw legend colored rectangles
  legend.append("rect")
      .attr("x", width - 18)
      .attr("y", 100)
      .attr("width", 18)
      .attr("height", 18)
      .style("fill", color);

  // draw legend text
  legend.append("text")
      .attr("x", width - 24)
      .attr("y", 105)
      .attr("dy", ".6em")
      .style("text-anchor", "end")
      .text(function(d) { return d;})
};

});